@@ -347,9 +347,9 @@ class CWF(object):
                 specialty_area_node.id = m[2]
                 specialty_area_node.title = m[1]
 
-                if data['NICE Specialty Area Description']:
+                if data['NICE Specialty Area Definition']:
                     specialty_area_node.description = \
-                        data['NICE Specialty Area Description']
+                        data['NICE Specialty Area Definition']
 
                 # create the node if it doesn't exist
                 graph.create(specialty_area_node)
@@ -376,8 +376,8 @@ class CWF(object):
                     # store the new relationship
                     graph.push(specialty_area_node)
 
-                if data['Work Role Description']:
-                    workrole_node.description = data['Work Role Description']
+                if data['Work Role Definition']:
+                    workrole_node.description = data['Work Role Definition']
 
                 if data['OPM Code (Fed Use)']:
                     workrole_node.opm_code = data['OPM Code (Fed Use)']
@@ -563,14 +563,11 @@ class CWF(object):
 
             # Cypher query to update the Competency description
             statement = """MATCH (n:NICECompetency)
-                        WHERE n.id = {n}
-                        SET n.description = {d}"""
+                        WHERE n.id = $n
+                        SET n.description = $d"""
 
             # Add to the transaction
-            tx.run(
-                statement,
-                {"n": row['Competency ID'], "d": row['Description']}
-            )
+            tx.run(statement, n=row['Competency ID'], d=row['Description'])
 
         # Commit the transactions to the databse
         tx.commit()
@@ -588,7 +585,7 @@ class CWF(object):
                 r'["Knowledge", "Skill", "Ability", "Task"],'
                 r'["id", "description"])')
         except ClientError as err:
-            if err.code == 'Neo.ClientError.Schema.IndexAlreadyExists':
+            if err.code == 'Neo.ClientError.Procedure.ProcedureCallFailed':
                 log.info('KSAT Index already exists')
             else:
                 raise err
